/**
 */
package de.mdelab.mlstorypatterns;

import java.util.Map;
import org.eclipse.emf.common.util.DiagnosticChain;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Abstract Story Pattern Link</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * Superclass of all links in a StoryPattern.
 * 
 * Source and target of a link must be contained in the same story pattern link
 * the link itself or in the containing pattern.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * </p>
 * <ul>
 *   <li>{@link de.mdelab.mlstorypatterns.AbstractStoryPatternLink#getSource <em>Source</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.AbstractStoryPatternLink#getTarget <em>Target</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.AbstractStoryPatternLink#getStoryPattern <em>Story Pattern</em>}</li>
 * </ul>
 *
 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getAbstractStoryPatternLink()
 * @model abstract="true"
 *        annotation="http://www.eclipse.org/emf/2002/Ecore constraints='AbstractStoryPatternLinkTargetCreated'"
 * @generated
 */
public interface AbstractStoryPatternLink extends StoryPatternElement {
	/**
	 * Returns the value of the '<em><b>Source</b></em>' reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.AbstractStoryPatternObject#getOutgoingLinks <em>Outgoing Links</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Source</em>' reference isn't clear, there
	 * really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Source</em>' reference.
	 * @see #setSource(AbstractStoryPatternObject)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getAbstractStoryPatternLink_Source()
	 * @see de.mdelab.mlstorypatterns.AbstractStoryPatternObject#getOutgoingLinks
	 * @model opposite="outgoingLinks" resolveProxies="false" required="true"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlstorypatterns/1.0!AbstractStoryPatternLink!source'"
	 * @generated
	 */
	AbstractStoryPatternObject getSource();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlstorypatterns.AbstractStoryPatternLink#getSource
	 * <em>Source</em>}' reference. <!-- begin-user-doc --> <!-- end-user-doc
	 * -->
	 * 
	 * @param value
	 *            the new value of the '<em>Source</em>' reference.
	 * @see #getSource()
	 * @generated
	 */
	void setSource(AbstractStoryPatternObject value);

	/**
	 * Returns the value of the '<em><b>Target</b></em>' reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.AbstractStoryPatternObject#getIncomingLinks <em>Incoming Links</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Target</em>' reference isn't clear, there
	 * really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Target</em>' reference.
	 * @see #setTarget(AbstractStoryPatternObject)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getAbstractStoryPatternLink_Target()
	 * @see de.mdelab.mlstorypatterns.AbstractStoryPatternObject#getIncomingLinks
	 * @model opposite="incomingLinks" resolveProxies="false" required="true"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlstorypatterns/1.0!AbstractStoryPatternLink!target'"
	 * @generated
	 */
	AbstractStoryPatternObject getTarget();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlstorypatterns.AbstractStoryPatternLink#getTarget
	 * <em>Target</em>}' reference. <!-- begin-user-doc --> <!-- end-user-doc
	 * -->
	 * 
	 * @param value
	 *            the new value of the '<em>Target</em>' reference.
	 * @see #getTarget()
	 * @generated
	 */
	void setTarget(AbstractStoryPatternObject value);

	/**
	 * Returns the value of the '<em><b>Story Pattern</b></em>' container reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.StoryPattern#getStoryPatternLinks <em>Story Pattern Links</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Story Pattern</em>' container reference isn't
	 * clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Story Pattern</em>' container reference.
	 * @see #setStoryPattern(StoryPattern)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getAbstractStoryPatternLink_StoryPattern()
	 * @see de.mdelab.mlstorypatterns.StoryPattern#getStoryPatternLinks
	 * @model opposite="storyPatternLinks" resolveProxies="false" required="true" transient="false"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlstorypatterns/1.0!AbstractStoryPatternLink!storyPattern'"
	 * @generated
	 */
	StoryPattern getStoryPattern();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.AbstractStoryPatternLink#getStoryPattern <em>Story Pattern</em>}' container reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param value the new value of the '<em>Story Pattern</em>' container reference.
	 * @see #getStoryPattern()
	 * @generated
	 */
	void setStoryPattern(StoryPattern value);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv AbstractStoryPatternLinkNACModifier:\n *   let\n *     severity : Integer[1] = \'AbstractStoryPatternLink::AbstractStoryPatternLinkNACModifier\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.storyPattern.containingPattern &lt;&gt; null implies self.modifier = ModifierEnum::NONE\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Story pattern link \' +\n *               self.toString() + \' in a NAC may not be modified.\', status = status\n *             }\n *           endif\n *       in\n *         \'AbstractStoryPatternLink::AbstractStoryPatternLinkNACModifier\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkNACModifier);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; storyPattern = this.getStoryPattern();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; containingPattern = storyPattern.getContainingPattern();\n\tfinal /*@NonInvalid\052/ boolean ne = containingPattern != null;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (ne) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier = this.getModifier();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq = BOXED_modifier == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_NONE;\n\t\timplies = eq;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_in_32_a_32_NAC_32_may_32_not_32_be_32_modified);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkNACModifier, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean AbstractStoryPatternLinkNACModifier(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv AbstractStoryPatternLinkSource:\n *   let\n *     severity : Integer[1] = \'AbstractStoryPatternLink::AbstractStoryPatternLinkSource\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.source &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Source of story pattern link \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'AbstractStoryPatternLink::AbstractStoryPatternLinkSource\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkSource);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkSource, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean AbstractStoryPatternLinkSource(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv AbstractStoryPatternLinkSourceDestroyed:\n *   let\n *     severity : Integer[1] = \'AbstractStoryPatternLink::AbstractStoryPatternLinkSourceDestroyed\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.source &lt;&gt; null and self.source.modifier = ModifierEnum::DESTROY implies self.modifier = ModifierEnum::DESTROY\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Story pattern link \' +\n *               self.toString() + \' must be destroyed because its source is destroyed.\', status = status\n *             }\n *           endif\n *       in\n *         \'AbstractStoryPatternLink::AbstractStoryPatternLinkSourceDestroyed\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkSourceDestroye);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; source = this.getSource();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier = source.getModifier();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_modifier == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_DESTROY;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier_0 = this.getModifier();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier_0 = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier_0.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq_0 = BOXED_modifier_0 == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_DESTROY;\n\t\timplies = eq_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_destroyed_32_because_32_its_32_source_32_is_32_destroyed);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkSourceDestroye, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean AbstractStoryPatternLinkSourceDestroyed(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv AbstractStoryPatternLinkTarget:\n *   let\n *     severity : Integer[1] = \'AbstractStoryPatternLink::AbstractStoryPatternLinkTarget\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.target &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Target of story pattern link \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'AbstractStoryPatternLink::AbstractStoryPatternLinkTarget\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkTarget);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkTarget, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean AbstractStoryPatternLinkTarget(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv AbstractStoryPatternLinkSourceCreated:\n *   let\n *     severity : Integer[1] = \'AbstractStoryPatternLink::AbstractStoryPatternLinkSourceCreated\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.source &lt;&gt; null and self.source.modifier = ModifierEnum::CREATE implies self.modifier = ModifierEnum::CREATE\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Story pattern link \' +\n *               self.toString() + \' must be created because its source is created.\', status = status\n *             }\n *           endif\n *       in\n *         \'AbstractStoryPatternLink::AbstractStoryPatternLinkSourceCreated\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkSourceCreated);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; source = this.getSource();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier = source.getModifier();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_modifier == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_CREATE;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier_0 = this.getModifier();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier_0 = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier_0.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq_0 = BOXED_modifier_0 == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_CREATE;\n\t\timplies = eq_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_created_32_because_32_its_32_source_32_is_32_created);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkSourceCreated, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean AbstractStoryPatternLinkSourceCreated(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv AbstractStoryPatternLinkSourceTargetPattern:\n *   let\n *     severity : Integer[1] = \'AbstractStoryPatternLink::AbstractStoryPatternLinkSourceTargetPattern\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.source &lt;&gt; null and self.target &lt;&gt; null implies\n *             (self.source.storyPattern = self.storyPattern or self.source.storyPattern = self.storyPattern.containingPattern\n *             ) and\n *             (self.target.storyPattern = self.storyPattern or self.target.storyPattern = self.storyPattern.containingPattern\n *             )\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Source and target of story pattern link \' +\n *               self.toString() + \' must reside in the same story pattern or its containing pattern.\', status = status\n *             }\n *           endif\n *       in\n *         \'AbstractStoryPatternLink::AbstractStoryPatternLinkSourceTargetPattern\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkSourceTargetPa);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; source_0 = this.getSource();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; storyPattern_0 = this.getStoryPattern();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; storyPattern_1 = source_0.getStoryPattern();\n\tfinal /*@NonInvalid\052/ boolean eq = storyPattern_1.equals(storyPattern_0);\n\t/*@NonInvalid\052/ boolean or;\n\tif (eq) {\n\t\tor = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; containingPattern = storyPattern_0.getContainingPattern();\n\t\tfinal /*@NonInvalid\052/ boolean eq_0 = storyPattern_1.equals(containingPattern);\n\t\tor = eq_0;\n\t}\n\t/*@NonInvalid\052/ boolean and;\n\tif (or) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; target_0 = this.getTarget();\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; storyPattern_5 = target_0.getStoryPattern();\n\t\tfinal /*@NonInvalid\052/ boolean eq_1 = storyPattern_5.equals(storyPattern_0);\n\t\t/*@NonInvalid\052/ boolean or_0;\n\t\tif (eq_1) {\n\t\t\tor_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t}\n\t\telse {\n\t\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; containingPattern_0 = storyPattern_0.getContainingPattern();\n\t\t\tfinal /*@NonInvalid\052/ boolean eq_2 = storyPattern_5.equals(containingPattern_0);\n\t\t\tor_0 = eq_2;\n\t\t}\n\t\tand = or_0;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (and) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Source_32_and_32_target_32_of_32_story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_reside_32_in_32_the_32_same_32_story_32_pattern_32_or_32_its_32_containing_32_pattern);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkSourceTargetPa, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean AbstractStoryPatternLinkSourceTargetPattern(
			DiagnosticChain diagnostics, Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv AbstractStoryPatternLinkTargetDestroyed:\n *   let\n *     severity : Integer[1] = \'AbstractStoryPatternLink::AbstractStoryPatternLinkTargetDestroyed\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.target &lt;&gt; null and self.target.modifier = ModifierEnum::DESTROY implies self.modifier = ModifierEnum::DESTROY\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Story pattern link \' +\n *               self.toString() + \' must be destroyed because its target is destroyed.\', status = status\n *             }\n *           endif\n *       in\n *         \'AbstractStoryPatternLink::AbstractStoryPatternLinkTargetDestroyed\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkTargetDestroye);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; target = this.getTarget();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier = target.getModifier();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_modifier == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_DESTROY;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier_0 = this.getModifier();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier_0 = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier_0.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq_0 = BOXED_modifier_0 == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_DESTROY;\n\t\timplies = eq_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_destroyed_32_because_32_its_32_target_32_is_32_destroyed);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkTargetDestroye, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean AbstractStoryPatternLinkTargetDestroyed(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv AbstractStoryPatternLinkTargetCreated:\n *   let\n *     severity : Integer[1] = \'AbstractStoryPatternLink::AbstractStoryPatternLinkTargetCreated\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.target &lt;&gt; null and self.target.modifier = ModifierEnum::CREATE implies self.modifier = ModifierEnum::CREATE\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Story pattern link \' +\n *               self.toString() + \' must be created because its target is created.\', status = status\n *             }\n *           endif\n *       in\n *         \'AbstractStoryPatternLink::AbstractStoryPatternLinkTargetCreated\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkTargetCreated);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; target = this.getTarget();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier = target.getModifier();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_modifier == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_CREATE;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier_0 = this.getModifier();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier_0 = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier_0.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq_0 = BOXED_modifier_0 == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_CREATE;\n\t\timplies = eq_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_created_32_because_32_its_32_target_32_is_32_created);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_AbstractStoryPatternLink_c_c_AbstractStoryPatternLinkTargetCreated, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean AbstractStoryPatternLinkTargetCreated(DiagnosticChain diagnostics,
			Map<Object, Object> context);

} // AbstractStoryPatternLink
