/**
 */
package de.mdelab.mlstorypatterns;

import de.mdelab.mlcore.MLAnnotatedElement;
import de.mdelab.mlcore.MLElementWithUUID;
import java.util.Map;
import org.eclipse.emf.common.util.DiagnosticChain;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Link Order Constraint</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * LinkOrderConstraints specify a relative ordering between two objects in an ordered link. Depending on the value of constraintType, the target object of successorLink must be a direct successor or any successor of the target of predecessorLink.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * </p>
 * <ul>
 *   <li>{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getConstraintType <em>Constraint Type</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getPredecessorLink <em>Predecessor Link</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getSuccessorLink <em>Successor Link</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getStoryPattern <em>Story Pattern</em>}</li>
 * </ul>
 *
 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint()
 * @model annotation="http://www.eclipse.org/emf/2002/Ecore constraints='LinkOrderConstraintMatchingFeature'"
 * @generated
 */
public interface LinkOrderConstraint
		extends
			MLElementWithUUID,
			MLAnnotatedElement {
	/**
	 * Returns the value of the '<em><b>Constraint Type</b></em>' attribute.
	 * The default value is <code>"ANY_SUCCESSOR"</code>.
	 * The literals are from the enumeration {@link de.mdelab.mlstorypatterns.LinkOrderConstraintEnum}.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Constraint Type</em>' attribute isn't clear,
	 * there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Constraint Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.LinkOrderConstraintEnum
	 * @see #setConstraintType(LinkOrderConstraintEnum)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint_ConstraintType()
	 * @model default="ANY_SUCCESSOR" required="true"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlstorypatterns/1.0!LinkOrderConstraint!constraintType'"
	 * @generated
	 */
	LinkOrderConstraintEnum getConstraintType();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getConstraintType <em>Constraint Type</em>}' attribute.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Constraint Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.LinkOrderConstraintEnum
	 * @see #getConstraintType()
	 * @generated
	 */
	void setConstraintType(LinkOrderConstraintEnum value);

	/**
	 * Returns the value of the '<em><b>Predecessor Link</b></em>' reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.StoryPatternLink#getOutgoingLinkOrderConstraints <em>Outgoing Link Order Constraints</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Predecessor Link</em>' reference isn't clear,
	 * there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Predecessor Link</em>' reference.
	 * @see #setPredecessorLink(StoryPatternLink)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint_PredecessorLink()
	 * @see de.mdelab.mlstorypatterns.StoryPatternLink#getOutgoingLinkOrderConstraints
	 * @model opposite="outgoingLinkOrderConstraints" resolveProxies="false" required="true"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlstorypatterns/1.0!LinkOrderConstraint!predecessorLink'"
	 * @generated
	 */
	StoryPatternLink getPredecessorLink();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getPredecessorLink <em>Predecessor Link</em>}' reference.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Predecessor Link</em>' reference.
	 * @see #getPredecessorLink()
	 * @generated
	 */
	void setPredecessorLink(StoryPatternLink value);

	/**
	 * Returns the value of the '<em><b>Successor Link</b></em>' reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.StoryPatternLink#getIncomingLinkOrderConstraints <em>Incoming Link Order Constraints</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Successor Link</em>' reference isn't clear,
	 * there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Successor Link</em>' reference.
	 * @see #setSuccessorLink(StoryPatternLink)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint_SuccessorLink()
	 * @see de.mdelab.mlstorypatterns.StoryPatternLink#getIncomingLinkOrderConstraints
	 * @model opposite="incomingLinkOrderConstraints" resolveProxies="false" required="true"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlstorypatterns/1.0!LinkOrderConstraint!successorLink'"
	 * @generated
	 */
	StoryPatternLink getSuccessorLink();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getSuccessorLink <em>Successor Link</em>}' reference.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Successor Link</em>' reference.
	 * @see #getSuccessorLink()
	 * @generated
	 */
	void setSuccessorLink(StoryPatternLink value);

	/**
	 * Returns the value of the '<em><b>Story Pattern</b></em>' container reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.StoryPattern#getLinkOrderConstraints <em>Link Order Constraints</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Story Pattern</em>' container reference isn't
	 * clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Story Pattern</em>' container reference.
	 * @see #setStoryPattern(StoryPattern)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint_StoryPattern()
	 * @see de.mdelab.mlstorypatterns.StoryPattern#getLinkOrderConstraints
	 * @model opposite="linkOrderConstraints" resolveProxies="false" required="true" transient="false"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlstorypatterns/1.0!LinkOrderConstraint!storyPattern'"
	 * @generated
	 */
	StoryPattern getStoryPattern();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getStoryPattern <em>Story Pattern</em>}' container reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param value the new value of the '<em>Story Pattern</em>' container reference.
	 * @see #getStoryPattern()
	 * @generated
	 */
	void setStoryPattern(StoryPattern value);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv LinkOrderConstraintPredecessorPosition:\n *   let\n *     severity : Integer[1] = \'LinkOrderConstraint::LinkOrderConstraintPredecessorPosition\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.predecessorLink &lt;&gt; null implies self.predecessorLink.linkPositionConstraint &lt;&gt; LinkPositionConstraintEnum::LAST\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The predecessor link of link order constraint \' +\n *               self.toString() + \' may not have the position constraint \\\'LAST\\\'.\', status = status\n *             }\n *           endif\n *       in\n *         \'LinkOrderConstraint::LinkOrderConstraintPredecessorPosition\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintPredecessorPosition);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt; predecessorLink = this.getPredecessorLink();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.LinkPositionConstraintEnum%&gt; linkPositionConstraint = predecessorLink.getLinkPositionConstraint();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_linkPositionConstraint = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_LinkPositionConstraintEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(linkPositionConstraint.getName()));\n\tfinal /*@NonInvalid\052/ boolean ne = BOXED_linkPositionConstraint != &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_LAST;\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (ne) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_The_32_predecessor_32_link_32_of_32_link_32_order_32_constraint_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_may_32_not_32_have_32_the_32_position_32_constraint_32_39_LAST_39_);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintPredecessorPosition, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean LinkOrderConstraintPredecessorPosition(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv LinkOrderConstraintSuccessor:\n *   let\n *     severity : Integer[1] = \'LinkOrderConstraint::LinkOrderConstraintSuccessor\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.successorLink &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Successor link of link order constraint \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'LinkOrderConstraint::LinkOrderConstraintSuccessor\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintSuccessor);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintSuccessor, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean LinkOrderConstraintSuccessor(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv LinkOrderConstraintSuccessorPosition:\n *   let\n *     severity : Integer[1] = \'LinkOrderConstraint::LinkOrderConstraintSuccessorPosition\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.successorLink &lt;&gt; null implies self.successorLink.linkPositionConstraint &lt;&gt; LinkPositionConstraintEnum::FIRST\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The successor link of link order constraint \' +\n *               self.toString() + \' may not have the position constraint \\\'FIRST\\\'.\', status = status\n *             }\n *           endif\n *       in\n *         \'LinkOrderConstraint::LinkOrderConstraintSuccessorPosition\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintSuccessorPosition);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt; successorLink = this.getSuccessorLink();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.LinkPositionConstraintEnum%&gt; linkPositionConstraint = successorLink.getLinkPositionConstraint();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_linkPositionConstraint = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_LinkPositionConstraintEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(linkPositionConstraint.getName()));\n\tfinal /*@NonInvalid\052/ boolean ne = BOXED_linkPositionConstraint != &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_FIRST;\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (ne) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_The_32_successor_32_link_32_of_32_link_32_order_32_constraint_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_may_32_not_32_have_32_the_32_position_32_constraint_32_39_FIRST_39_);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintSuccessorPosition, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean LinkOrderConstraintSuccessorPosition(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv LinkOrderConstraintPredecessor:\n *   let\n *     severity : Integer[1] = \'LinkOrderConstraint::LinkOrderConstraintPredecessor\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.predecessorLink &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Predecessor link of link order constraint \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'LinkOrderConstraint::LinkOrderConstraintPredecessor\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintPredecessor);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintPredecessor, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean LinkOrderConstraintPredecessor(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv LinkOrderConstraintPredecessorFeature:\n *   let\n *     severity : Integer[1] = \'LinkOrderConstraint::LinkOrderConstraintPredecessorFeature\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.predecessorLink &lt;&gt; null and self.predecessorLink.feature &lt;&gt; null implies self.predecessorLink.feature.ordered and self.predecessorLink.feature.many\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The feature of the predecessor link of link order constraint \' +\n *               self.toString() + \' must be ordered and many-valued.\', status = status\n *             }\n *           endif\n *       in\n *         \'LinkOrderConstraint::LinkOrderConstraintPredecessorFeature\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintPredecessorFeature);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt; predecessorLink_0 = this.getPredecessorLink();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt; feature_0 = predecessorLink_0.getFeature();\n\tfinal /*@NonInvalid\052/ boolean ordered = feature_0.isOrdered();\n\t/*@NonInvalid\052/ boolean and;\n\tif (ordered) {\n\t\tfinal /*@NonInvalid\052/ boolean many = feature_0.isMany();\n\t\tand = many;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (and) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_The_32_feature_32_of_32_the_32_predecessor_32_link_32_of_32_link_32_order_32_constraint_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_ordered_32_and_32_many_m_valued);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintPredecessorFeature, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean LinkOrderConstraintPredecessorFeature(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv LinkOrderConstraintType:\n *   let\n *     severity : Integer[1] = \'LinkOrderConstraint::LinkOrderConstraintType\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.constraintType &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Constraint type of link order constraint \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'LinkOrderConstraint::LinkOrderConstraintType\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintType);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintType, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean LinkOrderConstraintType(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv LinkOrderConstraintMatchingFeature:\n *   let\n *     severity : Integer[1] = \'LinkOrderConstraint::LinkOrderConstraintMatchingFeature\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.predecessorLink &lt;&gt; null and self.successorLink &lt;&gt; null implies self.predecessorLink.feature = self.successorLink.feature\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The features of the predecessor and successor link of link order constraint \' +\n *               self.toString() + \' must be the same.\', status = status\n *             }\n *           endif\n *       in\n *         \'LinkOrderConstraint::LinkOrderConstraintMatchingFeature\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintMatchingFeature);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt; predecessorLink = this.getPredecessorLink();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt; feature = predecessorLink.getFeature();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt; successorLink = this.getSuccessorLink();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt; feature_0 = successorLink.getFeature();\n\tfinal /*@NonInvalid\052/ boolean eq = feature.equals(feature_0);\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (eq) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_The_32_features_32_of_32_the_32_predecessor_32_and_32_successor_32_link_32_of_32_link_32_order, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_the_32_same);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_LinkOrderConstraint_c_c_LinkOrderConstraintMatchingFeature, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean LinkOrderConstraintMatchingFeature(DiagnosticChain diagnostics,
			Map<Object, Object> context);

} // LinkOrderConstraint
