/**
 */
package de.mdelab.mlstorypatterns;

import de.mdelab.mlcore.MLAnnotatedElement;
import de.mdelab.mlcore.MLElementWithUUID;
import java.util.Map;
import org.eclipse.emf.common.util.DiagnosticChain;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Story Pattern Element</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * Superclass of all elements that may be contained in a StoryPattern, i.e., objects and links.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * </p>
 * <ul>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternElement#getModifier <em>Modifier</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternElement#getMatchType <em>Match Type</em>}</li>
 * </ul>
 *
 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternElement()
 * @model abstract="true"
 *        annotation="http://www.eclipse.org/emf/2002/Ecore constraints='StoryPatternElementOptional'"
 * @generated
 */
public interface StoryPatternElement
		extends
			MLElementWithUUID,
			MLAnnotatedElement {
	/**
	 * Returns the value of the '<em><b>Modifier</b></em>' attribute. The
	 * literals are from the enumeration
	 * {@link de.mdelab.mlstorypatterns.ModifierEnum}. <!-- begin-user-doc -->
	 * <!-- end-user-doc --> <!-- begin-model-doc --> The modifier specifies how
	 * the element is modified, when the StoryPattern is applied, i.e., whether
	 * the element is created, deleted, or left unchanged. <!-- end-model-doc
	 * -->
	 * 
	 * @return the value of the '<em>Modifier</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.ModifierEnum
	 * @see #setModifier(ModifierEnum)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternElement_Modifier()
	 * @model required="true"
	 * @generated
	 */
	ModifierEnum getModifier();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlstorypatterns.StoryPatternElement#getModifier
	 * <em>Modifier</em>}' attribute. <!-- begin-user-doc --> <!-- end-user-doc
	 * -->
	 * 
	 * @param value
	 *            the new value of the '<em>Modifier</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.ModifierEnum
	 * @see #getModifier()
	 * @generated
	 */
	void setModifier(ModifierEnum value);

	/**
	 * Returns the value of the '<em><b>Match Type</b></em>' attribute. The
	 * literals are from the enumeration
	 * {@link de.mdelab.mlstorypatterns.MatchTypeEnum}. <!-- begin-user-doc -->
	 * <!-- end-user-doc --> <!-- begin-model-doc --> The match type can be used
	 * to specify that the element has to be matched in a special way. <!--
	 * end-model-doc -->
	 * 
	 * @return the value of the '<em>Match Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.MatchTypeEnum
	 * @see #setMatchType(MatchTypeEnum)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternElement_MatchType()
	 * @model required="true"
	 * @generated
	 */
	MatchTypeEnum getMatchType();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.StoryPatternElement#getMatchType <em>Match Type</em>}' attribute.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Match Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.MatchTypeEnum
	 * @see #getMatchType()
	 * @generated
	 */
	void setMatchType(MatchTypeEnum value);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternElementOptional:\n *   let\n *     severity : Integer[1] = \'StoryPatternElement::StoryPatternElementOptional\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.matchType = MatchTypeEnum::OPTIONAL implies self.modifier = ModifierEnum::CREATE or self.modifier = ModifierEnum::DESTROY\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Optional story pattern element \' +\n *               self.toString() + \' must be created or destroyed.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternElement::StoryPatternElementOptional\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternElement_c_c_StoryPatternElementOptional);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.MatchTypeEnum%&gt; matchType = this.getMatchType();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_matchType = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_MatchTypeEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(matchType.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_matchType == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_OPTIONAL;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier_0 = this.getModifier();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier_0 = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier_0.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq_0 = BOXED_modifier_0 == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_CREATE;\n\t\t/*@NonInvalid\052/ boolean or;\n\t\tif (eq_0) {\n\t\t\tor = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t}\n\t\telse {\n\t\t\tfinal /*@NonInvalid\052/ boolean eq_1 = BOXED_modifier_0 == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_DESTROY;\n\t\t\tor = eq_1;\n\t\t}\n\t\timplies = or;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Optional_32_story_32_pattern_32_element_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_created_32_or_32_destroyed);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternElement_c_c_StoryPatternElementOptional, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternElementOptional(DiagnosticChain diagnostics,
			Map<Object, Object> context);

} // StoryPatternElement
