package de.mdelab.mlstorypatterns.diagram.custom.edit.parts;

import org.eclipse.draw2d.ColorConstants;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.emf.edit.EMFEditPlugin;
import org.eclipse.emf.edit.provider.ComposedAdapterFactory;
import org.eclipse.emf.edit.provider.IItemLabelProvider;
import org.eclipse.gmf.runtime.notation.View;

import de.mdelab.mlcallactions.CallAction;
import de.mdelab.mlcallactions.CallActionExpression;
import de.mdelab.mlcallactions.CallActionParameter;
import de.mdelab.mlexpressions.MLExpression;
import de.mdelab.mlstorypatterns.AttributeAssignment;
import de.mdelab.mlstorypatterns.diagram.edit.parts.AttributeAssignmentEditPart;

public class CustomAttributeAssignmentEditPart extends AttributeAssignmentEditPart implements IMLExpressionEditPart {

	public CustomAttributeAssignmentEditPart(View view)
	{
		super(view);
	}

	/*
	 * should be similar to addNotationalListeners of:
	 * 
	 * CustomActivityEdgeGuardConstraintLabelEditPart
	 * CustomActivityFinalNodeReturnValueLabelEditPart
	 * CustomAttributeAssignmentEditPart CustomCallActionExpressionEditPart
	 * CustomCallActionExpression2EditPart CustomCallActionExpression3EditPart
	 * CustomStoryPatternExpressionLinkFeatureNameLabelEditPart
	 * CustomStoryPatternObjectClassifierLabelEditPart
	 */
	@Override
	protected void addNotationalListeners()	{
		super.addNotationalListeners();
		
		if (((View) getModel()).getElement() instanceof AttributeAssignment){
			MLExpression expr = ((AttributeAssignment) ((View) getModel()).getElement()).getAssignmentExpression();
			//	JOptionPane.showInputDialog(expr + "ccd");
			EStructuralFeature feat = ((AttributeAssignment) ((View) getModel()).getElement()).getFeature();
			String s = ((AttributeAssignment) ((View) getModel()).getElement()).getUuid();
		
			addListenerFilter(s, this, feat);
			
			if (expr != null) {
				
				// DB: Bug #1802 Use utility class
				addListenerFilter( EditPartUtil.getFilterId( expr ), this, expr );
//				addListenerFilter(expr.eClass().getName(), this, expr);
	
				if (expr instanceof CallActionExpression) {
					final TreeIterator<EObject> it = ((CallActionExpression) expr).eAllContents();
					
					for ( EObject eObj; it.hasNext(); ) {
						eObj = it.next();
						
						// DB: Bug #1802
						addListenerFilter( EditPartUtil.getFilterId( eObj ), this, eObj );
//						addListenerFilter(Utility.getFilterId((MLNamedElement) eObj), this, eObj);
					}
				}
			}
		}
	}

	@Override
	protected void refreshVisuals()
	{
		super.refreshVisuals();
		updateFigure();
	}

	protected void updateFigure()
	{
		String text = "[]";
		//if(((StoryPatternImpl)((View) getModel()).getElement()).getStoryPatternObjects()!=null){
			//if(((StoryPatternImpl)((View) getModel()).getElement()).getStoryPatternObjects().size()>0){
			//	if (((StoryPatternObject)((StoryPatternImpl)((View) getModel()).getElement()).getStoryPatternObjects().get(0)).getAttributeAssignments()!=null){
				//	if (((StoryPatternObject)((StoryPatternImpl)((View) getModel()).getElement()).getStoryPatternObjects().get(0)).getAttributeAssignments().size()>0){
					//	AttributeAssignment aa = ((AttributeAssignment) ((StoryPatternObject)((StoryPatternImpl)((View) getModel()).getElement()).getStoryPatternObjects().get(0)).getAttributeAssignments().get(0));
						AttributeAssignment aa = ((AttributeAssignment) ((View) getModel()).getElement());
						text = "[ ]";
						try{
							ComposedAdapterFactory factory = new ComposedAdapterFactory(EMFEditPlugin.getComposedAdapterFactoryDescriptorRegistry());
							//if (aa.getAssignmentExpression()!=null)
							//text = ((IItemLabelProvider) factory.adapt(aa.getAssignmentExpression(), IItemLabelProvider.class)).getText(aa.getAssignmentExpression());
							if (aa.getFeature() != null)
							{
								text = "[" + aa.getFeature().getName() + "] := ";
							}
							else
							{
								text = "[null] := ";
							}
					
							if (aa.getAssignmentExpression() != null)
							{
								text += "[" + ((IItemLabelProvider) factory.adapt(aa.getAssignmentExpression(), IItemLabelProvider.class)).getText(aa.getAssignmentExpression()) + "]";
							}
							else
							{
								text += "[null]";
							}		
						}
						catch (Exception e){
							e.printStackTrace();
						}
						//}
					//}
				//}
			//}
		
		

		
		setLabelText(text);


		getFigure().setBackgroundColor(ColorConstants.blue);

		getFigure().setForegroundColor(MlstorypatternsDiagramConstants.MODIFIER_CREATE_COLOR);
	}

	@Override
	protected void handleNotificationEvent(Notification event)
	{
		Object notifier = event.getNotifier();
		Object newValue = event.getNewValue();
		Object oldValue = event.getOldValue();
		int eventType = event.getEventType();

		if ((eventType == Notification.SET || eventType == Notification.ADD)
				&& (newValue instanceof CallAction || newValue instanceof MLExpression || newValue instanceof CallActionParameter))
		{
			this.addListenerFilter(((EObject)newValue).eClass().getName(), this, (EObject) newValue);
			updateFigure();
		}
		else if (eventType == Notification.REMOVE
				&& (oldValue instanceof CallAction || oldValue instanceof MLExpression || oldValue instanceof CallActionParameter))
		{
			// DB: Bug #1802
			this.removeListenerFilter(EditPartUtil.getFilterId((EObject) oldValue));
			updateFigure();
		}
		else if (notifier instanceof AttributeAssignment || notifier instanceof CallAction || notifier instanceof MLExpression
				|| notifier instanceof CallActionParameter)
		{
			updateFigure();
		}

		super.handleNotificationEvent(event);
	}

	@Override
	public MLExpression getMLExpression() {
		return ( (AttributeAssignment) ( (View) getModel() ).getElement() ).getAssignmentExpression();
	}
}
